Class: ConfirmSiteSetup
- Defined in:
- lib/sakai-cle-test-api/page_objects/site_setup.rb
Overview
The Confirmation page at the end of a Course Site Setup
Instance Method Summary collapse
-
#create_site ⇒ Object
For portfolio sites…
-
#request_site ⇒ Object
Clicks the Request Site button, then instantiates the SiteSetup Class.
Methods inherited from BasePage
basic_page_elements, frame_element
Methods inherited from PageMaker
element, expected_element, expected_title, #initialize, #method_missing, page_url
Constructor Details
This class inherits a constructor from PageMaker
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class PageMaker
Instance Method Details
#create_site ⇒ Object
For portfolio sites… Clicks the “Create Site” button and instantiates the SiteSetup class.
595 596 597 598 |
# File 'lib/sakai-cle-test-api/page_objects/site_setup.rb', line 595 def create_site frm.(:value=>"Create Site").click SiteSetup.new(@browser) end |
#request_site ⇒ Object
Clicks the Request Site button, then instantiates the SiteSetup Class.
587 588 589 590 |
# File 'lib/sakai-cle-test-api/page_objects/site_setup.rb', line 587 def request_site frm.(:value=>"Request Site").click SiteSetup.new(@browser) end |