Class: SakaiCLE
- Inherits:
-
Object
- Object
- SakaiCLE
- Defined in:
- lib/sakai-cle-test-api.rb
Overview
Initialize this class at the start of your test cases to open the specified test browser at the specified Sakai welcome page URL.
The initialization will return the LoginPage class object as well as create the @browser variable used throughout the page classes
Instance Attribute Summary collapse
-
#browser ⇒ Object
readonly
include PageObject include ToolsMenu.
Instance Method Summary collapse
-
#initialize(web_browser, url) ⇒ SakaiCLE
constructor
A new instance of SakaiCLE.
-
#page ⇒ Object
Returns the class containing the welcome page’s page elements.
Constructor Details
#initialize(web_browser, url) ⇒ SakaiCLE
Returns a new instance of SakaiCLE.
20 21 22 23 24 |
# File 'lib/sakai-cle-test-api.rb', line 20 def initialize(web_browser, url) @browser = Watir::Browser.new web_browser @browser.window.resize_to(1400,900) @browser.goto url end |
Instance Attribute Details
#browser ⇒ Object (readonly)
include PageObject include ToolsMenu
18 19 20 |
# File 'lib/sakai-cle-test-api.rb', line 18 def browser @browser end |
Instance Method Details
#page ⇒ Object
Returns the class containing the welcome page’s page elements.
27 28 29 |
# File 'lib/sakai-cle-test-api.rb', line 27 def page Login.new @browser end |